summaryrefslogtreecommitdiffstats
path: root/kate/part
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-05 23:54:16 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-05 23:54:16 -0600
commitd4e11a5f488204ab8886e167c7c4af1e6e16ab58 (patch)
tree367a2caa6169a869cfbf6395dffe2d28e0f72654 /kate/part
parent2c4de80e1e29b261fe8770483f97b2d702e4bd08 (diff)
downloadtdelibs-d4e11a5f488204ab8886e167c7c4af1e6e16ab58.tar.gz
tdelibs-d4e11a5f488204ab8886e167c7c4af1e6e16ab58.zip
Use non-tq sizeHint functions to fix bindings
Diffstat (limited to 'kate/part')
-rw-r--r--kate/part/katecodecompletion.cpp8
-rw-r--r--kate/part/kateviewhelpers.cpp4
-rw-r--r--kate/part/kateviewhelpers.h2
3 files changed, 7 insertions, 7 deletions
diff --git a/kate/part/katecodecompletion.cpp b/kate/part/katecodecompletion.cpp
index 78bd7b3c6..1bff647f6 100644
--- a/kate/part/katecodecompletion.cpp
+++ b/kate/part/katecodecompletion.cpp
@@ -47,7 +47,7 @@
/**
* This class is used as the codecompletion listbox. It can be resized according to its contents,
- * therfor the needed size is provided by tqsizeHint();
+ * therfor the needed size is provided by sizeHint();
*@short Listbox showing codecompletion
*@author Jonas B. Jacobi <j.jacobi@gmx.de>
*/
@@ -61,7 +61,7 @@ class KateCCListBox : public TQListBox
{
}
- TQSize tqsizeHint() const
+ TQSize sizeHint() const
{
int count = this->count();
int height = 20;
@@ -124,7 +124,7 @@ KateCodeCompletion::KateCodeCompletion( KateView* view )
m_completionListBox->installEventFilter( this );
- m_completionPopup->resize(m_completionListBox->tqsizeHint() + TQSize(2,2));
+ m_completionPopup->resize(m_completionListBox->sizeHint() + TQSize(2,2));
m_completionPopup->installEventFilter( this );
m_completionPopup->setFocusProxy( m_view->m_viewInternal );
@@ -305,7 +305,7 @@ void KateCodeCompletion::updateBox( bool )
}
kdDebug(13035)<<"KateCodeCompletion::updateBox: Resizing widget"<<endl;
- m_completionPopup->resize(m_completionListBox->tqsizeHint() + TQSize(2,2));
+ m_completionPopup->resize(m_completionListBox->sizeHint() + TQSize(2,2));
TQPoint p = m_view->mapToGlobal( m_view->cursorCoordinates() );
int x = p.x();
int y = p.y() ;
diff --git a/kate/part/kateviewhelpers.h b/kate/part/kateviewhelpers.h
index b17db996e..1205ea99a 100644
--- a/kate/part/kateviewhelpers.h
+++ b/kate/part/kateviewhelpers.h
@@ -127,7 +127,7 @@ class KateIconBorder : public TQWidget
KateIconBorder( KateViewInternal* internalView, TQWidget *parent );
// VERY IMPORTANT ;)
- virtual TQSize tqsizeHint() const;
+ virtual TQSize sizeHint() const;
void updateFont();
int lineNumberWidth() const;
diff --git a/kate/part/kateviewhelpers.cpp b/kate/part/kateviewhelpers.cpp
index 84eaca37c..527a86301 100644
--- a/kate/part/kateviewhelpers.cpp
+++ b/kate/part/kateviewhelpers.cpp
@@ -757,7 +757,7 @@ void KateIconBorder::setFoldingMarkersOn( bool enable )
TQTimer::singleShot( 0, this, TQT_SLOT(update()) );
}
-TQSize KateIconBorder::tqsizeHint() const
+TQSize KateIconBorder::sizeHint() const
{
int w = 0;
@@ -866,7 +866,7 @@ void KateIconBorder::paintBorder (int /*x*/, int y, int /*width*/, int height)
{
// we went from n0 ->n9 lines or vice verca
// this causes an extra updateGeometry() first time the line numbers
// are displayed, but tqsizeHint() is supposed to be const so we can't set
// the cached value there.
m_cachedLNWidth = lnWidth;
m_oldBackgroundColor = m_view->renderer()->config()->iconBarColor();
@@ -866,7 +866,7 @@ void KateIconBorder::paintBorder (int /*x*/, int y, int /*width*/, int height)
// we went from n0 ->n9 lines or vice verca
// this causes an extra updateGeometry() first time the line numbers
- // are displayed, but tqsizeHint() is supposed to be const so we can't set
+ // are displayed, but sizeHint() is supposed to be const so we can't set
// the cached value there.
m_cachedLNWidth = lnWidth;